Module: EncodedId::Rails::Model::ClassMethods
- Defined in:
- lib/encoded_id/rails/model.rb
Instance Method Summary collapse
-
#encoded_id_config(**options) ⇒ Object
Configure encoder options for this specific model.
-
#encoded_id_options ⇒ Object
Walks up the inheritance chain to find options if not set on this class.
Instance Method Details
#encoded_id_config(**options) ⇒ Object
Configure encoder options for this specific model
48 49 50 |
# File 'lib/encoded_id/rails/model.rb', line 48 def encoded_id_config(**) @encoded_id_options = end |
#encoded_id_options ⇒ Object
Walks up the inheritance chain to find options if not set on this class
54 55 56 57 58 59 60 61 62 |
# File 'lib/encoded_id/rails/model.rb', line 54 def return @encoded_id_options if defined?(@encoded_id_options) && @encoded_id_options if superclass.respond_to?(:encoded_id_options) superclass. else {} end end |